@@ -18,7 +18,7 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
  * 
  *
- * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/gtk2perl.h,v 1.42 2006/08/07 18:36:01 kaffeetisch Exp $
+ * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/gtk2perl.h,v 1.45 2007/12/16 16:53:32 kaffeetisch Exp $
  */
 
 #ifndef _GTK2PERL_H_
@@ -35,12 +35,30 @@
   GType gtk2perl_gdk_region_get_type (void) G_GNUC_CONST;
 #endif
 
+/* custom GType for PangoAttribute */
+#ifndef PANGO_TYPE_ATTRIBUTE
+# define PANGO_TYPE_ATTRIBUTE (gtk2perl_pango_attribute_get_type ())
+  GType gtk2perl_pango_attribute_get_type (void) G_GNUC_CONST;
+#endif
+
+/* custom GType for PangoAttrIter */
+#ifndef PANGO_TYPE_ATTR_ITERATOR
+# define PANGO_TYPE_ATTR_ITERATOR (gtk2perl_pango_attr_iterator_get_type ())
+  GType gtk2perl_pango_attr_iterator_get_type (void) G_GNUC_CONST;
+#endif
+
 /* custom GType for PangoLayoutIter */
 #ifndef PANGO_TYPE_LAYOUT_ITER
 # define PANGO_TYPE_LAYOUT_ITER (gtk2perl_pango_layout_iter_get_type ())
   GType gtk2perl_pango_layout_iter_get_type (void) G_GNUC_CONST;
 #endif
 
+/* custom GType for PangoLayoutLine */
+#ifndef PANGO_TYPE_LAYOUT_LINE
+# define PANGO_TYPE_LAYOUT_LINE (gtk2perl_pango_layout_line_get_type ())
+  GType gtk2perl_pango_layout_line_get_type (void) G_GNUC_CONST;
+#endif
+
 /* custom GType for PangoScriptIter */
 #if PANGO_CHECK_VERSION (1, 4, 0)
 # ifndef PANGO_TYPE_SCRIPT_ITER
@@ -79,7 +97,7 @@ custom handling for GdkBitmaps, since there are no typemacros for them.
 /* GObject derivative GdkBitmap */
 #define SvGdkBitmap(sv)       ((GdkBitmap*)gperl_get_object_check (sv, GDK_TYPE_DRAWABLE))
 typedef GdkBitmap GdkBitmap_ornull;
-#define SvGdkBitmap_ornull(sv)        (((sv) && SvOK (sv)) ? SvGdkBitmap(sv) : NULL)
+#define SvGdkBitmap_ornull(sv)        (gperl_sv_defined (sv) ? SvGdkBitmap(sv) : NULL)
 typedef GdkBitmap GdkBitmap_noinc;
 /* these are real functions, rather than macros, because there's some extra
  * work involved in making sure it's blessed into Gtk2::Gdk::Bitmap when no
@@ -94,6 +112,7 @@ void SvGdkGCValues (SV * data, GdkGCValues * v, GdkGCValuesMask * m);
 
 /* exported for various other parts of pango */
 SV * newSVPangoRectangle (PangoRectangle * rectangle);
+PangoRectangle * SvPangoRectangle (SV * sv);
 
 /*
  * GdkAtom, an opaque pointer
@@ -166,7 +185,7 @@ void gtk2perl_read_gtk_target_entry (SV * sv, GtkTargetEntry * entry);
 SV * newSVGtkTargetList (GtkTargetList * list);
 #define newSVGtkTargetList_ornull(list)	((list) ? newSVGtkTargetList (list) : &PL_sv_undef)
 GtkTargetList * SvGtkTargetList (SV * sv);
-#define SvGtkTargetList_ornull(sv)	(((sv) && SvOK (sv)) ? SvGtkTargetList (sv) : NULL)
+#define SvGtkTargetList_ornull(sv)	(gperl_sv_defined (sv) ? SvGtkTargetList (sv) : NULL)
 
 /*
  * exported so Gnome2 can reuse it in wrappers.  other modules might want to
